@@ -34,7 +34,7 @@ dedup_keys <- function(x) {
 }
 
 str_breaks <- function(x) {
-  z <- split_str(x, 80L) # from src/split_str.cpp
+  z <- str_splitter(x, 80L)
   paste0(z, collapse = "\n")
 }
 
@@ -50,10 +50,8 @@ prep_interaction <- function(x, file, bytes) {
   } else {
     get_body(x$response$body)
   }
-  body_nchar <- tryCatch(nchar(body), error = function(e) e)
-  body <- enc2utf8(body)
   if (length(body) == 0 || !nzchar(body)) body <- ""
-  list(
+  res = list(
     list(
       request = list(
         method = x$request$method,
@@ -68,7 +66,7 @@ prep_interaction <- function(x, file, bytes) {
         status = x$response$status,
         headers = dedup_keys(x$response$headers),
         body = list(
-          encoding = encoding_guess(x$response$body, bytes),
+          encoding = "",
           file = x$response$disk,
           string = body
         )
@@ -77,6 +75,11 @@ prep_interaction <- function(x, file, bytes) {
       recorded_with = pkg_versions()
     )
   )
+  if (bytes) {
+    str_index <- which(grepl("string", names(res[[1]]$response$body)))
+    names(res[[1]]$response$body)[str_index] <- "base64_string"
+  }
+  return(res)
 }
 
 # param x: a list with "request" and "response" slots
@@ -85,6 +88,7 @@ prep_interaction <- function(x, file, bytes) {
 write_interactions <- function(x, file, bytes) {
   z <- prep_interaction(x, file, bytes)
   z <- headers_remove(z)
+  z <- query_params_remove(z)
   tmp <- yaml::as.yaml(z)
   tmp <- sensitive_remove(tmp)
   cat(tmp, file = file, append = TRUE)
@@ -93,6 +97,7 @@ write_interactions <- function(x, file, bytes) {
 write_interactions_json <- function(x, file, bytes) {
   z <- prep_interaction(x, file, bytes)
   z <- headers_remove(z)
+  z <- query_params_remove(z)
   # combine with existing data on same file, if any
   on_disk <- invisible(tryCatch(jsonlite::fromJSON(file, FALSE),
     error = function(e) e))
