@@ -26,7 +26,7 @@ invisible(vcr::vcr_configure(
   write_disk_path = "../files"
 ))
 vcr::check_cassette_names()'
-  cat(z, file = file.path(dir, "tests/testthat/setup-rabbit.R"))
+  cat(z, file = file.path(dir, "tests/testthat/helper-rabbit.R"))
 
   file_string <- '{
   "args": {
@@ -84,8 +84,8 @@ vcr::check_cassette_names()'
   on.exit(setwd(og))
 
   mm <- testthat::test_dir("tests/testthat", reporter = testthat::ListReporter$new())
-  expect_equal(capture.output(mm[[1]]$results[[1]]), "As expected ")
-  expect_equal(capture.output(mm[[1]]$results[[2]]), "As expected ")
+  expect_equal(capture.output(mm[[1]]$results[[1]])[2], "As expected")
+  expect_equal(capture.output(mm[[1]]$results[[2]])[2], "As expected")
 
   # cleanup
   unlink(dir, TRUE, TRUE)
